@@ -179,16 +179,26 @@ class DataVolume(NamespacedResource):
             if self.source == "http" or "registry":
                 self.res["spec"]["source"][self.source]["url"] = self.url
             if self.cert_configmap:
-                self.res["spec"]["source"][self.source]["certConfigMap"] = self.cert_configmap
+                self.res["spec"]["source"][self.source][
+                    "certConfigMap"
+                ] = self.cert_configmap
             if self.source == "upload" or self.source == "blank":
                 self.res["spec"]["source"][self.source] = {}
             if self.hostpath_node:
                 self.res["metadata"].setdefault("annotations", {}).update(
-                    {f"{NamespacedResource.ApiGroup.KUBEVIRT_IO}/provisionOnNode": (self.hostpath_node)}
+                    {
+                        f"{NamespacedResource.ApiGroup.KUBEVIRT_IO}/provisionOnNode": (
+                            self.hostpath_node
+                        )
+                    }
                 )
             if self.multus_annotation:
                 self.res["metadata"].setdefault("annotations", {}).update(
-                    {f"{NamespacedResource.ApiGroup.K8S_V1_CNI_CNCF_IO}/networks": (self.multus_annotation)}
+                    {
+                        f"{NamespacedResource.ApiGroup.K8S_V1_CNI_CNCF_IO}/networks": (
+                            self.multus_annotation
+                        )
+                    }
                 )
             if self.bind_immediate_annotation:
                 self.res["metadata"].setdefault("annotations", {}).update(
@@ -203,7 +213,11 @@ class DataVolume(NamespacedResource):
                 self.res["spec"]["preallocation"] = self.preallocation
             if self.delete_after_completion:
                 self.res["metadata"].setdefault("annotations", {}).update(
-                    {f"{self.api_group}/storage.deleteAfterCompletion": (self.delete_after_completion)}
+                    {
+                        f"{self.api_group}/storage.deleteAfterCompletion": (
+                            self.delete_after_completion
+                        )
+                    }
                 )
 
     def wait_deleted(self, timeout=TIMEOUT_4MINUTES):
@@ -219,15 +233,14 @@ class DataVolume(NamespacedResource):
         super().wait_deleted(timeout=timeout)
         return self.pvc.wait_deleted(timeout=timeout)
 
-    def wait(self, timeout=TIMEOUT_10MINUTES, failure_timeout=TIMEOUT_2MINUTES, wait_for_exists_only=False):
-        if wait_for_exists_only:
-            return super().wait(timeout=timeout)
-        else:
-            self._check_none_pending_status(failure_timeout=failure_timeout)
+    def wait(self, timeout=TIMEOUT_10MINUTES, failure_timeout=TIMEOUT_2MINUTES):
+        self._check_none_pending_status(failure_timeout=failure_timeout)
 
-            # If DV's status is not Pending, continue with the flow
-            self.wait_for_status(status=self.Status.SUCCEEDED, timeout=timeout)
-            self.pvc.wait_for_status(status=PersistentVolumeClaim.Status.BOUND, timeout=timeout)
+        # If DV's status is not Pending, continue with the flow
+        self.wait_for_status(status=self.Status.SUCCEEDED, timeout=timeout)
+        self.pvc.wait_for_status(
+            status=PersistentVolumeClaim.Status.BOUND, timeout=timeout
+        )
 
     @property
     def pvc(self):
@@ -239,7 +252,11 @@ class DataVolume(NamespacedResource):
 
     @property
     def scratch_pvc(self):
-        scratch_pvc_prefix = self.pvc.prime_pvc.name if self.pvc.use_populator else self.name
+        scratch_pvc_prefix = (
+            f"prime-{self.pvc.instance.metadata.uid}"
+            if self.pvc.use_populator
+            else self.name
+        )
         return PersistentVolumeClaim(
             name=f"{scratch_pvc_prefix}-scratch",
             namespace=self.namespace,
@@ -303,7 +320,9 @@ class DataVolume(NamespacedResource):
         self._check_none_pending_status(failure_timeout=failure_timeout)
 
         sample = None
-        status_of_dv_str = f"Status of {self.kind} '{self.name}' in namespace '{self.namespace}':\n"
+        status_of_dv_str = (
+            f"Status of {self.kind} '{self.name}' in namespace '{self.namespace}':\n"
+        )
         try:
             for sample in TimeoutSampler(
                 sleep=1,
@@ -311,9 +330,11 @@ class DataVolume(NamespacedResource):
                 func=lambda: self.exists,
             ):
                 # DV reach to success if the status is succeeded or if the DV does not exist
-                if sample is None or sample.get("status", {}).get("phase") == self.Status.SUCCEEDED:
+                if sample is None or sample.status.phase == self.Status.SUCCEEDED:
                     break
-                elif stop_status_func and stop_status_func(*stop_status_func_args, **stop_status_func_kwargs):
+                elif stop_status_func and stop_status_func(
+                    *stop_status_func_args, **stop_status_func_kwargs
+                ):
                     raise TimeoutExpiredError(
                         value=(
                             "Exited on the stop_status_func"
@@ -327,7 +348,9 @@ class DataVolume(NamespacedResource):
             raise
 
         # For CSI storage, PVC gets Bound after DV succeeded
-        return self.pvc.wait_for_status(status=PersistentVolumeClaim.Status.BOUND, timeout=TIMEOUT_1MINUTE)
+        return self.pvc.wait_for_status(
+            status=PersistentVolumeClaim.Status.BOUND, timeout=TIMEOUT_1MINUTE
+        )
 
     def delete(self, wait=False, timeout=TIMEOUT_4MINUTES, body=None):
         """
